==> ckan-2.0.tar.gz: ckan-2.0/ckan/public/base/i18n/ru.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ru",
    "plural-forms": "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);"
  },
  "An Error Occurred": [
    null,
    "Возникла ошибка"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Вы уверены, что хотите выполнить это действие?"
  ],
  "Cancel": [
    null,
    "Отменить"
  ],
  "Confirm": [
    null,
    "Потверждение"
  ],
  "Edit": [
    null,
    "Редактировать"
  ],
  "Failed to load data API information": [
    null,
    "Не удалось загрузить данные API "
  ],
  "Follow": [
    null,
    "Следить"
  ],
  "Hide": [
    null,
    "Спрятать"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Слишком коротко, должен быть хотя бы один символ"
  ],
  "Loading...": [
    null,
    "Идет загрузка..."
  ],
  "No matches found": [
    null,
    "Совпадений не найдено"
  ],
  "Please Confirm Action": [
    null,
    "Пожалуйста, подтвердите действие"
  ],
  "Resource uploaded": [
    null,
    "Ресурс загружен"
  ],
  "Show more": [
    null,
    "Показать еще"
  ],
  "Start typing…": [
    null,
    "Начните вводить ..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Есть несохраненные изменения в этой форме"
  ],
  "There is no API data to load for this resource": [
    null,
    "Нет API данных для загрузки для данного ресурса"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Не удается загрузить аутентификации"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Невозможно получить данные для загружаемого файла"
  ],
  "Unable to upload file": [
    null,
    "Невозможно загрузить файл"
  ],
  "Unfollow": [
    null,
    "Не следовать"
  ],
  "Upload a file": [
    null,
    "Вложить файл"
  ],
  "show less": [
    null,
    "показать меньше"
  ],
  "show more": [
    null,
    "показать еще"
  ]
}

==> ckan-2.1.1.tar.gz: ckan-2.1.1/ckan/public/base/i18n/ru.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ru",
    "plural-forms": "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);"
  },
  "An Error Occurred": [
    null,
    "Возникла ошибка"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Вы уверены, что хотите выполнить это действие?"
  ],
  "Cancel": [
    null,
    "Отменить"
  ],
  "Confirm": [
    null,
    "Потверждение"
  ],
  "Edit": [
    null,
    "Редактировать"
  ],
  "Failed to load data API information": [
    null,
    "Не удалось загрузить данные API "
  ],
  "Follow": [
    null,
    "Следить"
  ],
  "Hide": [
    null,
    "Спрятать"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Слишком коротко, должен быть хотя бы один символ"
  ],
  "Loading...": [
    null,
    "Идет загрузка..."
  ],
  "No matches found": [
    null,
    "Совпадений не найдено"
  ],
  "Please Confirm Action": [
    null,
    "Пожалуйста, подтвердите действие"
  ],
  "Resource uploaded": [
    null,
    "Ресурс загружен"
  ],
  "Show more": [
    null,
    "Показать еще"
  ],
  "Start typing…": [
    null,
    "Начните вводить ..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Есть несохраненные изменения в этой форме"
  ],
  "There is no API data to load for this resource": [
    null,
    "Нет API данных для загрузки для данного ресурса"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Не удается загрузить аутентификации"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Невозможно получить данные для загружаемого файла"
  ],
  "Unable to upload file": [
    null,
    "Невозможно загрузить файл"
  ],
  "Unfollow": [
    null,
    "Не следовать"
  ],
  "Upload a file": [
    null,
    "Вложить файл"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Вы загружаете файл. Вы уверены что хотите прервать ?"
  ],
  "show less": [
    null,
    "показать меньше"
  ],
  "show more": [
    null,
    "показать еще"
  ]
}
